@@ -18,7 +18,6 @@ from .permissions import make_writable, recursive_make_writable
 from ...base.context import context
 from ...common.compat import on_win
 from ...common.constants import CONDA_TEMP_EXTENSION
-from ...exceptions import CondaDependencyError
 if not on_win:
     from ...common.path import which
 
@@ -69,21 +68,25 @@ def unlink_or_rename_to_trash(path):
         make_writable(path)
         unlink(path)
     except EnvironmentError:
-        if on_win:
-            # on windows, it is important to use the rename program, as just using python's
-            #    rename leads to permission errors when files are in use.
-            condabin_dir = join(context.conda_prefix, "condabin")
-            trash_script = join(condabin_dir, 'rename_tmp.bat')
-            if not exists(trash_script):
-                raise CondaDependencyError("{} is missing.  Conda was not installed correctly.  "
-                                           "Please file an issue on the conda github repo.".format(
-                                               trash_script))
-            _dirname, _fn = split(path)
-            p = Popen(['cmd.exe', '/C', trash_script, _dirname, _fn, _fn + ".trash"],
-                      stdout=PIPE, stderr=PIPE)
-            stdout, stderr = p.communicate()
-        else:
+        try:
             rename(path, path + ".trash")
+        except EnvironmentError:
+            if on_win:
+                # on windows, it is important to use the rename program, as just using python's
+                #    rename leads to permission errors when files are in use.
+                condabin_dir = join(context.conda_prefix, "condabin")
+                trash_script = join(condabin_dir, 'rename_tmp.bat')
+                if exists(trash_script):
+                    _dirname, _fn = split(path)
+                    p = Popen(['cmd.exe', '/C', trash_script, _dirname, _fn, _fn + ".trash"],
+                              stdout=PIPE, stderr=PIPE)
+                    stdout, stderr = p.communicate()
+                else:
+                    log.debug("{} is missing.  Conda was not installed correctly or has been "
+                              "corrupted.  Please file an issue on the conda github repo."
+                              .format(trash_script))
+            log.warn("Could not remove or rename {}.  Please remove this file manually (you may "
+                     "need to reboot to free file handles)".format(path))
 
 
 def remove_empty_parent_paths(path):
