@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2012 Anaconda, Inc
+# SPDX-License-Identifier: BSD-3-Clause
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 from platform import machine
@@ -122,9 +124,26 @@ class LeasedPathType(Enum):
 class PackageType(Enum):
     NOARCH_GENERIC = 'noarch_generic'
     NOARCH_PYTHON = 'noarch_python'
-    NOARCH_PRELINK_PYTHON = 'noarch_prelink_python'
-    SHADOW_PRIVATE_ENV = 'shadow_private_env'
-    SHADOW_PIP = 'shadow_pip'
+    VIRTUAL_PRIVATE_ENV = 'virtual_private_env'
+    VIRTUAL_PYTHON_WHEEL = 'virtual_python_wheel'  # manageable
+    VIRTUAL_PYTHON_EGG_MANAGEABLE = 'virtual_python_egg_manageable'
+    VIRTUAL_PYTHON_EGG_UNMANAGEABLE = 'virtual_python_egg_unmanageable'
+    VIRTUAL_PYTHON_EGG_LINK = 'virtual_python_egg_link'  # unmanageable
+
+    @staticmethod
+    def conda_package_types():
+        return {
+            None,
+            PackageType.NOARCH_GENERIC,
+            PackageType.NOARCH_PYTHON,
+        }
+
+    @staticmethod
+    def unmanageable_package_types():
+        return {
+            PackageType.VIRTUAL_PYTHON_EGG_UNMANAGEABLE,
+            PackageType.VIRTUAL_PYTHON_EGG_LINK,
+        }
 
 
 class NoarchType(Enum):
